@@ -6,7 +6,7 @@ import logging
 import pika
 import pika.exceptions
 
-from kuyruk import exceptions
+from kuyruk import exceptions, importer
 from kuyruk.task import Task
 from kuyruk.queue import Queue
 from kuyruk.config import Config
@@ -14,7 +14,7 @@ from kuyruk.worker import Worker
 from kuyruk.events import EventMixin
 from kuyruk.connection import Connection
 
-__version__ = '0.24.1'
+__version__ = '0.24.2'
 __all__ = ['Kuyruk', 'Task', 'Worker']
 
 
@@ -54,13 +54,14 @@ class Kuyruk(EventMixin):
     """
     Reject = exceptions.Reject  # Shortcut for raising from tasks
 
-    def __init__(self, config=None, task_class=Task):
-        self.task_class = task_class
+    def __init__(self, config=None, task_class=None):
         self.config = Config()
         self._connection = None
         self._channel = None
         if config:
             self.config.from_object(config)
+        self.task_class = (importer.import_class_str(self.config.TASK_CLASS)
+                           if task_class is None else task_class)
 
     def task(self, queue='kuyruk', eager=False, retry=0, task_class=None,
              max_run_time=None, local=False, arg_class=None):
